package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(D@`````````0```````
M`*$X``````!``#@`"`!``!8`%0````8````$`````````$``````````0```
M``````!``````````<`````````!P``````````(`````P````0````````"
M``````````(``````````@``````````&``````````8``````````$````!
M````!0```````````````````````````````````````)E@````````F6``
M```````0``````$````&````````F]@```````"KV````````*O8````````
M!*`````````5`````````!```````@````8```````";^````````*OX````
M````J_@````````!H`````````&@``````````AD=.50````!````````).<
M````````DYP```````"3G`````````#4`````````-0`````````!&1TY5$`
M```&````````````````````````````````````````````````````````
M```````09'3E4@````0```````";V````````*O8````````J]@````````$
M*`````````0H``````````$O;&EB+VQD+6UU<VPM<S,Y,'@N<V\N,0`````1
M````20````0````(@`1`!0`0$""$`(:`!!``*`D$``D``"&""`($ND$8@(@`
M````````20```$T```!1````4@```%@```!9````6@````````!<````70``
M``````!>````7P```&$``````````'R:?VH.[]/J+4?>SA_?Q6^VF\4N#O&-
MN'S49-0.Y/\A'%AQV6!LH?HL/^7";XL!LH?7^D(!QD?B?)+CN](\PU5FS*]G
MTW`'B.S514/MVV(SS"6,%9N<J7\*`J?@4)X::TG[X*,`````````````````
M`````````````````````P``!P```````!AP```````````````,$@``````
M``````````````````````&S$@`````````````````````````````4$0``
M``````````````````````````'9$0````````````````````````````%5
M$@`````````````````````````````;$@``````````````````````````
M``&2$@`````````````````````````````C$@``````````````````````
M```````J$@````````````````````````````'F$@``````````````````
M``````````&>$@`````````````````````````````S(```````````````
M``````````````,8(0````````````````````````````!+$@``````````
M``````````````````!1$@````````````````````````````+E$@``````
M``````````````````````+6$@````````````````````````````)K$@``
M``````````````````````````(,$@````````````````````````````!8
M$@````````````````````````````*@$@``````````````````````````
M``!?$@````````````````````````````!G$@``````````````````````
M``````*)$@````````````````````````````!O$@``````````````````
M``````````!U$@````````````````````````````!^(```````````````
M``````````````+/$@````````````````````````````":$@``````````
M``````````````````"?$@````````````````````````````'W$0``````
M``````````````````````*G$@````````````````````````````(Y$@``
M``````````````````````````"F$@````````````````````````````(K
M$@````````````````````````````,\$@``````````````````````````
M``,7$0````````````````````````````)=$@``````````````````````
M``````,$$@````````````````````````````,9$0``````````````````
M``````````"M$@````````````````````````````+\$@``````````````
M``````````````%C$@````````````````````````````"V(@``````````
M``````````````````#%(`````````````````````````````#;$@``````
M``````````````````````+'$@````````````````````````````))$@``
M``````````````````````````#@$@````````````````````````````#F
M(`````````````````````````````*4$@``````````````````````````
M``$`$@````````````````````````````&#$@``````````````````````
M``````$%$@````````````````````````````)Y$@``````````````````
M``````````%R$@````````````````````````````$+$@``````````````
M``````````````$<$@````````````````````````````('$@``````````
M``````````````````!P$@````````````````````````````(8$@``````
M``````````````````````)2$@````````````````````````````+U$@``
M``````````````````````````$B$@````````````````````````````+M
M$@````````````````````````````$V$@``````````````````````````
M``("$@````````````````````````````'!$@``````````````````````
M``````$]$@````````````````````````````,6(0``````````````````
M``````````%.$@````````````````````````````,1$@``"0```````"`8
M`````````BH```'3$@``"@```````%8(``````````(```-^$@``"0``````
M`#((````````!DH```0J$@``"0```````#P8`````````&P```-;$@``"0``
M`````"O@``````````8```/H$@``!P```````!AP``````````(```.A$@``
M"0```````#A8`````````\````0.$@``"0```````"OH`````````>X```/9
M$```$P```````+!X``````````````-L$@``"0```````#%8`````````*P`
M``.+$@``"0```````"HH`````````#P```.3$@``"0```````#"X````````
M`'````.W$@``"0```````%-``````````6````/,$@``"0```````"W8````
M`````!X```0E$```$P```````,#8``````````````,A$@``"0```````")X
M`````````#P```/N$@``"0```````"WX`````````38```/"$0``$@``````
M`+!P``````````@```0'$```$@```````+!X``````````````/>$@``"0``
M`````")(``````````````/E$@``"0```````%+0`````````&P```,J$@``
M"0```````#$H`````````"X```-%$@``"0```````"K(`````````18```0;
M$@``"0```````%2@`````````1@```/Z$@``"0```````"\P`````````8@`
M;&EB<&5R;"YS;P!O<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!S;G!R
M:6YT9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P:60`=6YL
M:6YK`&UE;6UO=F4`<W1R;F-M<`!L<W1A=`!C;&]S961I<@!?251-7V1E<F5G
M:7-T97)434-L;VYE5&%B;&4`;W!E;@!S=')S='(`<W1R8VAR`')E861L:6YK
M`%]?8WAA7V9I;F%L:7IE`%]?<F5G:7-T97)?9G)A;65?:6YF;P!E>&ET`&-L
M;W-E`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`<F5A9`!R;61I<@!?7V5R
M<FYO7VQO8V%T:6]N`&UK9&ER`'!T:')E861?9V5T<W!E8VEF:6,`;65M8W!Y
M`%]?<W1A8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R;%]S
M>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L
M7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E
M<FQ?<W9?,G!V7V9L86=S`%]F:6YI`%!,7V1O7W5N9'5M<`!097)L7VYE=UA3
M7V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?
M871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P
M97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C
M:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL
M;V,`<&5R;%]A;&QO8P!L:6)C+FUU<VPM<S,Y,'@N<V\N,0!F<')I;G1F`'-T
M<F1U<`!P=&AR96%D7V%T9F]R:P!R96%D9&ER`'-P<FEN=&8`<W1R=&]K`'-T
M<FYC<'D`7U]L:6)C7W-T87)T7VUA:6X`7U]?96YV:7)O;@!?<W1A<G1?8P!G
M971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8W5R<F5N=%]E>&5C7W!R
M;V,`<&%R7V-U<G)E;G1?97AE8P!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT
M;7!D:7(`>'-?:6YI=`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?
M0D]/5`!S:&%?=7!D871E`&UY7W!A<E]P;`!P87)?8F%S96YA;64`7U]B<W-?
M<W1A<G0`<VAA7VEN:70`<&%R7V1I<FYA;64`<&%R7VEN:71?96YV`%]E9&%T
M80!P87)?9FEN9'!R;V<`<VAA7V9I;F%L`%]E;F0`<&%R7V-L96%N=7``+W5S
M<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4``````````````*^(````````
M``P````````@&````````*^@``````````P```````!6"````````*^X````
M``````P````````8<````````+````````````P```````"P`````````+`0
M``````````P```````!6*@```````+`8``````````P```````!6,```````
M`+`H``````````P```````!6,@```````+`P``````````P```````!6-@``
M`````+`X``````````P```````!6/@```````+!```````````P```````!6
MJ@```````+!(``````````P```````!61@```````+!8``````````P`````
M``!62@```````+!@``````````P```````!64````````+!P``````````P`
M``````!9"@```````*^0````!`````H``````````````````*^8````!0``
M``H``````````````````*^H````#0````H``````````````````*^P````
M'`````H``````````````````*_`````(`````H``````````````````*_(
M````*0````H``````````````````*_0````+0````H`````````````````
M`*_8````+@````H``````````````````*_@````,P````H`````````````
M`````*_H````.`````H``````````````````*_P````.0````H`````````
M`````````*_X````/@````H``````````````````*VP`````@````L`````
M`````````````*VX`````P````L``````````````````*W`````!@````L`
M`````````````````*W(````!P````L``````````````````*W0````"```
M``L``````````````````*W8````"0````L``````````````````*W@````
M"@````L``````````````````*WH````"P````L``````````````````*WP
M````#`````L``````````````````*WX````#0````L`````````````````
M`*X`````#P````L``````````````````*X(````$`````L`````````````
M`````*X0````$0````L``````````````````*X8````$@````L`````````
M`````````*X@````$P````L``````````````````*XH````%`````L`````
M`````````````*XP````%0````L``````````````````*XX````%@````L`
M`````````````````*Y`````%P````L``````````````````*Y(````&```
M``L``````````````````*Y0````&0````L``````````````````*Y8````
M&@````L``````````````````*Y@````&P````L``````````````````*YH
M````'0````L``````````````````*YP````'@````L`````````````````
M`*YX````'P````L``````````````````*Z`````(0````L`````````````
M`````*Z(````(@````L``````````````````*Z0````(P````L`````````
M`````````*Z8````)`````L``````````````````*Z@````)0````L`````
M`````````````*ZH````)P````L``````````````````*ZP````*`````L`
M`````````````````*ZX````*@````L``````````````````*[`````*P``
M``L``````````````````*[(````+`````L``````````````````*[0````
M+0````L``````````````````*[8````+@````L``````````````````*[@
M````+P````L``````````````````*[H````,`````L`````````````````
M`*[P````,0````L``````````````````*[X````,@````L`````````````
M`````*\`````-`````L``````````````````*\(````-0````L`````````
M`````````*\0````-@````L``````````````````*\8````-P````L`````
M`````````````*\@````.@````L``````````````````*\H````.P````L`
M`````````````````*\P````/`````L``````````````````*\X````/0``
M``L``````````````````*]`````/P````L``````````````````*](````
M0`````L``````````````````*]0````00````L``````````````````*]8
M````0@````L``````````````````*]@````0P````L`````````````````
M`*]H````1`````L``````````````````*]P````10````L`````````````
M`````*]X````1@````L``````````````````*^`````2`````L`````````
M`.OO\'``)+D$``^G^_]@XP#P```DP.4```6NP.4``!Z7Z^_Q$``$!_[C$/`X
M`"3`$```2GW2!_`P$`CC$!`0``0'\0<`!P`'`,`0``!*?.,0$```!`?Q#1#C
M$!`,`!3`]/___^4`````P!```$IPXQ`0```$!_$-$.,0$`P`%,#T____U0``
M`!C`$```2F3C$!````0'\0T0XQ`0#``4P/3____%````,,`0``!*6.,0$```
M!`?Q#1#C$!`,`!3`]/___[4```!(P!```$I,XQ`0```$!_$-$.,0$`P`%,#T
M____I0```&#`$```2D#C$!````0'\0T0XQ`0#``4P/3___^5````>,`0``!*
M-.,0$```!`?Q#1#C$!`,`!3`]/___X4```"0P!```$HHXQ`0```$!_$-$.,0
M$`P`%,#T____=0```*C`$```2ASC$!````0'\0T0XQ`0#``4P/3___]E````
MP,`0``!*$.,0$```!`?Q#1#C$!`,`!3`]/___U4```#8P!```$H$XQ`0```$
M!_$-$.,0$`P`%,#T____10```/#`$```2?CC$!````0'\0T0XQ`0#``4P/3_
M__\U```!",`0``!)[.,0$```!`?Q#1#C$!`,`!3`]/___R4```$@P!```$G@
MXQ`0```$!_$-$.,0$`P`%,#T____%0```3C`$```2=3C$!````0'\0T0XQ`0
M#``4P/3___\%```!4,`0``!)R.,0$```!`?Q#1#C$!`,`!3`]/___O4```%H
MP!```$F\XQ`0```$!_$-$.,0$`P`%,#T___^Y0```8#`$```2;#C$!````0'
M\0T0XQ`0#``4P/3___[5```!F,`0``!)I.,0$```!`?Q#1#C$!`,`!3`]/__
M_L4```&PP!```$F8XQ`0```$!_$-$.,0$`P`%,#T___^M0```<C`$```28SC
M$!````0'\0T0XQ`0#``4P/3___ZE```!X,`0``!)@.,0$```!`?Q#1#C$!`,
M`!3`]/___I4```'XP!```$ETXQ`0```$!_$-$.,0$`P`%,#T___^A0```A#`
M$```26CC$!````0'\0T0XQ`0#``4P/3___YU```"*,`0``!)7.,0$```!`?Q
M#1#C$!`,`!3`]/___F4```)`P!```$E0XQ`0```$!_$-$.,0$`P`%,#T___^
M50```EC`$```243C$!````0'\0T0XQ`0#``4P/3___Y%```"<,`0``!)..,0
M$```!`?Q#1#C$!`,`!3`]/___C4```*(P!```$DLXQ`0```$!_$-$.,0$`P`
M%,#T___^)0```J#`$```22#C$!````0'\0T0XQ`0#``4P/3___X5```"N,`0
M``!)%.,0$```!`?Q#1#C$!`,`!3`]/___@4```+0P!```$D(XQ`0```$!_$-
M$.,0$`P`%,#T___]]0```NC`$```2/SC$!````0'\0T0XQ`0#``4P/3___WE
M```#`,`0``!(\.,0$```!`?Q#1#C$!`,`!3`]/___=4```,8P!```$CDXQ`0
M```$!_$-$.,0$`P`%,#T___]Q0```S#`$```2-CC$!````0'\0T0XQ`0#``4
MP/3___VU```#2,`0``!(S.,0$```!`?Q#1#C$!`,`!3`]/___:4```-@P!``
M`$C`XQ`0```$!_$-$.,0$`P`%,#T___]E0```WC`$```2+3C$!````0'\0T0
MXQ`0#``4P/3___V%```#D,`0``!(J.,0$```!`?Q#1#C$!`,`!3`]/___74`
M``.HP!```$B<XQ`0```$!_$-$.,0$`P`%,#T___]90```\#`$```2)#C$!``
M``0'\0T0XQ`0#``4P/3___U5```#V,`0``!(A.,0$```!`?Q#1#C$!`,`!3`
M]/___44```/PP!```$AXXQ`0```$!_$-$.,0$`P`%,#T___]-0``!`C`$```
M2&SC$!````0'\0T0XQ`0#``4P/3___TE```$(,`0``!(8.,0$```!`?Q#1#C
M$!`,`!3`]/___14```0XP!```$A4XQ`0```$!_$-$.,0$`P`%,#T___]!0``
M!%#`$```2$CC$!````0'\0T0XQ`0#``4P/3___SU```$:,`0``!(/.,0$```
M!`?Q#1#C$!`,`!3`]/___.4```2`P!```$@PXQ`0```$!_$-$.,0$`P`%,#T
M___\U0``!)C`$```2"3C$!````0'\0T0XQ`0#``4P/3___S%```$L,`0``!(
M&.,0$```!`?Q#1#C$!`,`!3`]/___+4```3(P!```$@,XQ`0```$!_$-$.,0
M$`P`%,#T___\I0``!.#`$```2`#C$!````0'\0T0XQ`0#``4P/3___R5```$
M^,`0``!'].,0$```!`?Q#1#C$!`,`!3`]/___(4```40P!```$?HXQ`0```$
M!_$-$.,0$`P`%,#T___\=0``!2C`$```1]SC$!````0'\0T0XQ`0#``4P/3_
M__QE```%0,`0``!'T.,0$```!`?Q#1#C$!`,`!3`]/___%4```58P!```$?$
MXQ`0```$!_$-$.,0$`P`%,#T___\10``!7#K;_`P`"3C\/](_W'C,/"H`"3C
M0/"@`"10(/"T04#PH$$P\*A!(/"TP.7___YLQ$@``$?9Q"@``$?2N00`-,#E
M___]`<08``!'GI4`$`"G=``?P.7___W'Q"L``$@PN0(`(J=T``>G*0`!P.7_
M__Y[P.7___[8Q!@``$>9XR`0```6P.7___]/D@`J(<2X``!'CN,@L```%L#E
M____1)8")(KC(+```!;`Y?___SQ8$/"TE@$DBNPA``4`V+D4`"+K(@`#``W`
MY?___HWCL/"H``3C$+````3C$"```"3`$```'`;C$"`(`"180/"TQ!@``$>U
MXQ`@$``DN00`4L`0```;^.,0(!@`),0K``!'S\`0``!'RA)$Y4P0```$IR@`
M`1@4ISD``+GRT!*G.P`!IQ8`:.P4``0`V*=*``.Y%``1ZQ$``P`-XQ%?^/]Q
MIVD``.5($````+D4`$3`,```!'K$*```1ZO`Y?___-P8LA(BIW0`"<0H``!'
MH<#E___^$ABRQ"@``$>:P.7___U[P"```!JGP.4```&=N0(`(J=T`"'`$```
M1X;C$!````*G=``+P"```!IMP.4```&+Q"L``$=XP!```$=UXQ`0```"IX0`
M",0H``!';<#E```-$L0H``!':\#E___^S,#E___[>;D4`"OK;_#H``0'_NL#
M``,`#>PC``0`V+D$`&"Y%``BXP:P```$ZR(``P`-XP)?^/\DI_3_@P<'!P<'
M![D$`"_`,````!+C,#```!BG^_]@IPD``.,`\```),#T````"0<'!P<``(F(
M!P<'!T%`(`C$6```1I[K;_`P`"3C\/]8_W'$:```1HGE2/"@``#C,"`$`!3$
M*```1G3`Y?___0GK;_#8``0'_@<'!P?`$```1N#`(```1MVY(``2!X[$&```
M1G.Y`@`1!XX'\<`@``!&T,`0``!&S;D)`!+K(0`#``KK,0`_``RY"``RZS,`
M`0`*N0(`,P>.Q!@``$9NN0(`$0>.P"```$:T!_'`$```1K"5`!``!W[KK_!0
M`"3`$```1E/C\/]@_W'C$!````*GA``(Q"@``$9@P.7___SYP!```$1.P+``
M`$1/N00`H;D)`+'KNP`#``JGN___Q!@``$:+N2$`&Z=$`!S`Y?___Z#`$```
M1A7C$!````*GA``(P"```#AQP.7___LBP!```$9OD@$0`.NO\/``!`?^IQL`
M`<0;``!&:.L1``,`#>,1H```!`WAI_3_T^OO\'``)./P_V#_<>OO\1``!`?^
M!P<'!\`0``!%_.,0$````J>$`!3`,```1DS`(```.#WK[_!P`"3C\/]@_W'`
MY?___*CK[_$0``3`]/___V('!P<'!P?K[_!P`"3C\/]@_W'K[_$0``0'_@<'
M!P?K;_`P`"3C\/]@_W&Y`@!RIX0`3,08``!%ON.0$````J>$`$2Y!`!CN00`
M1^,00```E!(1IW0`+AM'N00`J;D4`(3CL*````*GA``>N00`2+D$`#?C(*``
M``3`Y?__^T,2(J=T`!]!&+``E3T0`*=T`!FY"0"I0;BP`>NJ``,`"E"@8`"Y
M!``KZV_PT``$!_ZG'@`]IX3_TD%`0`&G]/_(0:"@"*?T_\^GN0``I_3_[.OO
M\'``)+)/`!#K$0`@``VR3P`1X_#_4/]Q03#PI-('\*@0*,#E____EK)/`!#K
M$0`@``VR3P`1U0?PJ!`HIX0`!<#E___]5^OO\2``!`?^ZZ_P4``DLD\`$./P
M_U#_<>L1`"``#;D$`+*R3P`10:#PI-('\*@0*+D$`#JY!``KP.7___]HN0(`
M(J=T`!&R3P`0ZQ$`(``-LD\`$=4'\*@0**>$`!_`Y?___27C$/"D`!3$*```
M11?K$0`#``WC$"````CC(!`(``3C(!```"2Y`@`BIX3_TD$0$`BG]/_TZZ_Q
M```$!_[K;_`P`"2R3P`0X_#_4/]QZQ$`(``-LD\`$;D$`**Y!`"ST@?PJ!`H
ME3TP`*=T``1!L#`!IP@``+D$`!NGF0``LEX`D:<4__ZY"0";03#PI+D$`"K`
MY?___PJY`@`BIX0`,J<(``"G&0``N00`,K)>`!.G%/_^N0D`$KDA`!FG1`")
MIQD``.,QL```D$(Q(`"G&P`!N0(`,Z=T__>G*```LD\`$+D4`"+K$0`@``VR
M3P`1U0?PJ!`HIX0`R<#E___\IL08``!$F^-@$```!*<9```8@:<;``'K(0`#
M``WC(F_X_P*G=/_W["@``@#8P!```$3]N10`(N,0$```$NLB``,`#:>$`!>Y
M!``RN00`)L#E___Y',08``!$<>,@$```)+D"`"*G=``CIRC__Z?T_[G`$```
M1-OE3!````'`Y?__^>6Y`@!RIX3_\;D4`$BY!``VZT0``P`-P.7___GGQ!@`
M`$1,XW`0```DN10`&,0H``!$1.L1``,`#>,@(```!$$1(`CE2!````!0@/"D
MN00`&N,@$```E!(BIX0`!J<N`#VG=`!/N0D`&KD4`!'$B```1"3C</"D`!1!
M*1`"ZW<``P`-XW"````(P.7___F>XR!P```DN0(`(J>$_Z?C$/"D`!3C((``
M``3K$0`#``WC$2````3C(*```)!"(!``0:"@`;D$`#'`*P```/]!$!`!IX0`
M!J<N`#VG=/_NDCTP`*<I``#C,K```)!",A``IRL``;D"`#.G=/_WI_3_+T$0
M$`&G]/^GZV_PX``$!_X'!P<'!P?K?_`X`"2R3P`0X_#^R/]QZQ$`(``-LD\`
M$;D"`*+2!_$P$"BGA``BE0"@`*>$`![`Y?__^#"Y`@""IX0`%T%P\*"Y!``H
MP.7___CEN0(`(J=T`!NY!``HP.7___E\N00`*L#E___ZY[)/`!#K$0`@``VR
M3P`1U0?Q,!`HIX0`;<#E___[F$&P(!/`$```%K^G"```N00`*[)=`!*G%/_^
MIX3_T<`0```6Q[D$`"NR70`2IQ3__J>$_\:Y!``JIQD``+D$`#NR7@`2IQ3_
M_J<I``"Y"0`:LEX`(Z<4__ZY"0`K&A+L(0`"`-BY%``BP.7___CAN00`6[D$
M`)*Y!`!*P#```!:;P.7___L5N00`-[D$`"G`Y?__^LZG+O__N00`*:>$`!58
M$/"XP!L``/``IQY``*=T``S`Y?___V2Y!``IP.7___JGI_3_?<#E___XHJ?T
M__;K?_%P``0'_@<'LD\`$.L1`"``#;)/`!'KO_!8`"3C\/[(_W&Y!`"R03#P
MH-('\3`0*,#E___XU!(BIW0`+A@26"#PN,`K``#P`*<N0`"GA``'PBT``*``
MIW0`#J<Y``*Y!``KP.7___>[$!*G&O__B!``'[D4`"&R3P`0ZQ$`(``-LD\`
M$=4'\3`0**>$``G`Y?__^N6G&```I_3_[>N_\9``!`?^!P<'!^OO\'``),08
M``!"R>/P_V#_<>,@$```%L#E___Z?,!0```TE<1(``!"SL`P```6">OO\1``
M!,#T___Z30<'!P?K;_`P`"3C\/]8_W'$N```0J;C(+```!;`8```%T#`Y?__
M^EG`Y?___\[C(+```!;`Y?__^E"Y!`!6Y4CPH```P$````;8P#```!7IP.7_
M__=RZV_PV``$!_X'!P<'!P?K;_`P`"2R3P`0X_#_4/UQZQ$`(``-XR#PJ`)Q
MLD\`$=('(``0*$&P\*;`8```%=+`Y?__]Y#`0```%<ZY!`!2ISD0`;D$`"O`
MY?__]S2G+O__IW0`%J>Y``"R3P`0XR#PJ`)QZQ$`(``-LD\`$=4'(``0**>$
M`$O`Y?__^DP2(NP@$``@<:=$_^CCH/"G`7&G21``N00`.KD$`"O`Y?__^+JY
M!`"2$B*G1/_7IRH``;D4`"+`Y?__]ZZY`@"RIX3_S+D4`(FY(0"ZIZ0`!KGH
M@!NY84"AN2$`NJ?$``:YZ(`:N6%`L;D$`$BY!``Z[)`0`2!RN00`*\#E___Y
MW$$8L`"2`!``I_3_JKD$`"OK;_#@`@0'_@<'P/3___]T!P?K;_`P`"2R3P`0
MX_#^P/YQN00`LNL1`"``#>,@\3@!<;)/`!&Y!`"#T@<@`!`HP"```!5(P.7_
M__QFISD`+[D$`)*Y!``KP.7___@%N0(`(J>$`!RY!``[P"```!4XP.7___S%
MLD\`$.,@\3@!<>L1`"``#;)/`!'5!R``$"BGA`"RP.7___FWIP@``+D$`!NY
M!``HIZD``,`P```5'T&`\3BR7@"AIQ3__D%P\*@;J\#E___Y0*>J``&Y!`!2
MN0(`5:>$_\F5`%``P!```!2_N>*`4;D"`)FGA``:IP@``+D$`!6Y!``ILET`
M$J<4__ZG=``.P#```!3QIRD``,#E___Y&;D$`%*G]/_;IP@``*<9``"Y!``E
MLEX`$J<4__X;%;D4`"'C(E___W&5+R``IX0`(!H:IQX/_Z<D_XWCL/"@`"3`
M8```%,K`0```%32G.1``N00`*,#E___V'*<J``'"+P``$`"GQ``.I_0``:<:
M__^Y%``A02)0`)(`(`"G]/_1N00`-[D$`"C`Y?__^+(2(J=T_[!8$/#`P!L`
M`/``PAT``(``IW3_IJ<Y``&Y!``HP.7___7>$B*G=/^<N00`.,`@```4@L#E
M___\#[D$`"C`Y?__]NZY!`"RI_3_0[D$`"OK;_%P`00'_@<'N00`$N,P$```
ME!(S!XY!$!`!ISX`+[GB@"&G]/_U!P>Y`@`RIX0`!I4`,`"G=``(P"```!04
MP/3___;%N00`(Z<(``"G&0``LEX`$J<4__ZYZ3`AXT`?__]QN2$`-*<D``:G
M/___IW0`!*<I``&G)P`4N2``-*=T`"V5+S``IX3_V<`@```4,Z?T_]?C0$__
M_W&G]/_NE2]``*>$__FYZ3`4XR!/__]QN2$`,J<I``&YXC`2XU!```"0N00`
M)*=?`"_C0$___W&G=``ZN00`0KGI,!3C($___W&Y(0`RIR0`!J<___^G=``$
MIQD``>-`3___<:<7`"BY"0!#[!0``@#9PAX``!``IR0`)*=+``'`(```0/CK
M[_!P`"3C\/]@_W'L0!``(''`Y?__]OS`(```0.GK[_$0``0'_J<7_[RG]/^9
ME2]``*>$_].G]/_6IRD```?^!P>R3P`0ZQ$`(``-LD\`$>OO\'``)./P_S#_
M<<`@```3O-('\,@0*,`0```R#=(A\*80"L#E___ZZ\`@```3LL#E___ZY<`@
M```3L,#E___ZW\`@```3K\#E___ZV<`@```3K<#E___ZT\`@```3K\#E___Z
MS<`@```3@<#E___ZQ\`@```3J<#E___ZP<`@```3J,#E___ZN\`@```3I\#E
M___ZM<`@```3;L#E___ZK\`@```3H,#E___Z@;D"`#*GA``(P"```!.,P.7_
M__KKP"```!.9P.7___IQN0(`,J>$``C`(```$P_`Y?__^MO`(```$Y+`Y?__
M^F&Y`@`RIX0`(,`@```3.<#E___ZR\`P```3F<`@```34,#E___ZPK)/`!#K
M$0`@``VR3P`1U0?PR!`HIX0`)<#E___WM\`@```3<L#E___Z.;D"`#*GA``'
MP"```!,_I_3_V*=)``K`,```$VI!(/"WP.7___4^$B*G=/_.03#PP:?T_^SK
M[_%```0'_L0=```_J*<>__^G=``OZ^_P<``DP"```!,;X_#_8/]QP.7___H(
MN0(`(J>$`!OC$"```)"5`"``IX0`%,`7````,+D#`!'L$3^_`57$'P``/X+$
M+```/W_K[_$0``0'_J<8``"G]/_TQ"P``#]T!_[K[_!P`"3C\/]@_W'`Y?__
M]V+`Y?__]9^Y`@`BIX0`!>,@(```!.OO\1``!`?^!P?K;_`P`"2Y!`"RX_#_
M8/]QP"```!,&P.7___F]N00`.[D"`&*GA``&E0!@`*=T``O`(```$O;K;_#0
M``3`]/__^A[`Y?__]1^Y`@`BIW0`+*<(``"Y!``;N00`-K)>`"&G%/_^IQD`
M`+D)`"NR7@`3IQ3__KD)`!9!(A`"P.7___2"P#```!+@N00`HL!0```2;;D$
M`$O`Y?__]K6Y!``ZI_3_R.MO\-``!`?^!P<'!^MO\#``)+)/`!#K$0`@``VR
M3P`1X_#^&/=QN00`DN,@\>`(<=('(``0*,`0```^Z\`@```2-](/\+`0"-('
M\,`0&-(O\.`0(-(/\,@04-('\-@08,#E___Y1KD"`+*GA``BE0"P`*>$`![`
MY?___W.Y!``KP.7___2.N00`LK)/`!#C(/'@"''K$0`@``VR3P`1U0<@`!`H
MIX0"T\#E___VFL#E____/[D"`+*G=``G0:#PR.,0H````J=T``?`L```$E^G
M]``;XR"@```$P.7___D)N0(`$J=T``:GJP`(I_3_ZI4`$`"GA/_ZP.7___12
MN0(`LJ>$__.G"```N00`&Z<I``"R7@`AIQ3__KD)`"OK(@`!``VG*P`!P.7_
M__/:N00`<KD$`*+C0+```)021*=T`)%!L/#@XX"P```"IX0`'>,@L```!,#E
M___XR[D"`**GA`"0E0"@`*>$`(S`Y?__^Q`2(J>$`(:Y!``JP.7___00N00`
M@D&P\+"Y`@"(IW0`"^.@L````J>$``:5`*``IW0`=*<(``"Y!``8I[D``+)>
M`+&G%/_^N00`)Z<9``"Y"0"XLEX`$J<4__ZY"0`7&K&GN@0$N10`N[D$`"O`
MY?__\W_C</"@`"2Y!`"BP%```!%KN00`2,`P```1TL!@```1S,#E___UK*<Y
M`<"Y!``JP.7___5%IR[__Z=T`$K`Y?__]2Y88"``IVX`$:>$`$'$&```/;&Y
M%`!FN00`6N-`D```!,`P```1L.,@$```!,#E___TI:>Y``"G]/\7N00`*KD4
M`$3`,```$91!L+`!0:"@`L#E___U<Z?T_UVGNP`(I_3_8>,@L```!,#E___Z
M?Q(BIX0`";D$`"K`Y?__\W^Y!`""I[L`"*?T_V]!,/$0N00`*L#E___S4AAR
M$B*GA``5Q!@``#UGN00`6N-`D```!,`P```1AN,@$```!,#E___T7:?T_[A8
M$/$HP!L``/``IQY``*=T_^98@/$LP.7___5]&8*G=/_>6!#Q*,`;```!_Z<>
M`<"G=/_5N00`*\#E___RW+D$`++`(```$83`Y?__]]RY`@`BIW0`S>.`D```
M!*<(``"G&0``N00`*+)>`!*G%/_^N0D`&*<>``.GQ`!$N10`(>,RC_S_<<`@
M```19;)=`".G%/_^IW0`-J<>``2GA``-IQK__+D4`!'C$8___W&5+Q``IW0`
M)^,@D`@``J>$`"*G"```IQD``+D$`#*R7@`3IQ3__KD)`!+"'@````.GQ``1
MXR$O_/]QP!```!$WLET`$J<4__ZG=``%XX"0"``$P.7___UH$B*G=`#5ISD`
M`+D$`"C`Y?__\MZY!`"2&-(2(J>$`,BG20`"ISG_[L#E___Q\4%@\>"G20`&
MN00`-KD$`"G`Y?__\_:5`/'@IW0`8I5#\>&G=`!>E4'QXJ=T`%J50_'CIW0`
M5I5(\>2G=`!2E47QY:=T`$ZG20`"ISG_QKD$`"G`Y?__\<6G20`IN00`-KD$
M`"G`Y?__\\S`$```$3W`4```$!KC$/"@`"2Y!`!*P#```!#4N00`*\#E___T
M6;D$`"K`Y?__]`2Y!``[P"````_VP.7___>(N00`*\#E___]1Z?T_=OC@)``
M``3`Y?__\E^Y!``RN00`*,#E___Z@+D"`(*G=/\II_3_)*=)``"G.0``N00`
M*;D4`)W`Y?__\7?`Y0``#>"Y!`""I4^``+D$`#:Y!``IP.7___-Y$B*G)``K
MN00`*:=Y`!3`Y?__\T^Y!``X09#QHT&`\;>Y!``IN00`:,#E```.IN-`D```
MD+D$`"C`,```$!2GFP`!IXL``L#E___S\Z=W__&2`/'?I_3_@[D4`$*Y!``V
MN00`*,#E```-V*?T_\+`,```#^S`(```#['`Y?__]Q7`Y?__\3;`$```$*>Y
M!`!BXQ#PH``DP%````]_N00`2L`P```01+D$`"O`Y?__\\&G.0'`N00`*\#E
M___S6J<N__^G=/]?P.7___-#6!`@`*<>`!&G=/]6IWH``<#E___Q",`0```0
M>>,0\*@`)+D$`&*Y%``7P%````]/XQ#PH``DN00`2L`P```0&+D$`"O`Y?__
M\XZG]/_-N00`*^MO\A@(!`?^!P<'!P<'ZV_P,``DX_#_8/]QQ*@``#NNXR"@
M```6P.7___-DN00`LN,@H```%L#E___S7-(`(+FPN,`@```/+<#E___V*[D"
M`"*GA``*E3$@`*=T``:5`"`!IX0`!<#E___[0,08```[A>,@$```%L#E___S
M.Z=9``NG20`!P#````_2P.7___&AN0(`(J=T`$W$J```.V[C(*```!;`Y?__
M\R2G60`#ITD``<`P```/OL#E___QBKD"`+*G=`"YQ)@``#M7XR"0```6P.7_
M__,-IUD``Z=)``'`,```#[C`Y?__\7.Y`@"RIX0`[,`@```.N,#E___UT;D"
M`**GA`#%XR"0```6P.7___+OXQ"P$``$N00`2N,P$```!,#E___Q=*?T`,_C
M$"`0``2GN``!XW`0*``$Q(@``#L;[)O__P#86""``,:]```[D:>D`!2Y%@`B
MP.7___+(IUD``+D4`$FY!``WP.7___!?N0(`HJ=T`!'$'0``.WJG&O__&9&G
M=/^(I[@``<2H```Z\J?T`$;$*```.VVY%``;ZQ$``P`-XV$@```$XQ"@```$
M6"`0#,`K`"`$`*<N!`"G=``1XR`0$``$IP@``+)=`":G%/_^IW3_T:>Z``&G
M]/^QXR"````6P.7___*`IUD``J=)``#C,*````3`Y?__\K:G]/_DN18`(J>Z
M``'`Y?__\FVY!``WP.7__^\X6""@`,:]```[):=$_^^G]/\TXR"@```6P.7_
M__)9XQ"P$``$P$````[UXS`0```$P.7___#=XQ"P$``$XQ`0```$D4`0#:>$
M_R_C(*```!;`Y?__\CWC$+`0``3C,!````3`Y?__[^2G]/\>P.7___?WN0(`
MHN,@D```%J>$`&#`Y?__\B7C$+`0``2Y!`!*XS`0```$P.7___"JN00`*L#E
M___QU<2X```Z5N,@L```%L#E___R#+D$`*+C(+```!;`Y?__\@2G20`!P#``
M``ZDP.7__^[\P$````ZIN00`,KD$`"K`Y?__\(+C(+```!;`Y?__\>R2`""Y
MP"````V>P.7___2\Q"L``#JIN0(`(J=T`"/$*```.I[`Y?__^S_$*P``.IRY
M`@`BIW0`%L`@```.@,#E___O"L#E___QQ\0X```ZB.,0L!``!.-`,```!*?T
M_M2G.0'`Q"@``#I_P.7___%DN00`4J<N`!&GA``9[!(``0#8PA\````!I\0`
M$<08```Z9\1(```Z:.,P$```!,`@```.7L#E___NU^MO\-``!`?^ZZ_P4``D
MX_#_8/]QN00`LL#E___XZ,#E___XU;D$`*+`Y?__^D`2(J>$`!ZY`@"[IX0`
M&I4`L`"GA``6P#````V?N00`*L#E___OO;D@`**G=``*N00`*^NO\/``!,#T
M___UV>NO\/``!`?^!P<'![)/`!#K$0`@``VR3P`1ZV_P,``DIUD`"./P_-#_
M<:>Y``#2!_,H$"A!$/"HN00`,>-+(#@`!.L$`"``#.,`,```),!*`````.-`
M,`@`)*>[``BG.P`0IU?_[:=)`$#C,!!H``3C,!!``(+C,!`0`(+C,!```(+L
M4R"_(57L4R`^`5;C4!"``"2G&P`(IT?_Z>,0(!@`!.,0\*``).-0(```!.,0
M\*@`!,(:6H)YF>,0("``".,`(!``!..@(`@`!.Q%(+\E5>Q%(#H%5KD(`$'C
M$/"@``2YYQ`0N8``&N,0\*``@N.`\+``!+D(`$'"BEJ">9GK&@`"``SC@/"@
M``CL&@`A'E;CL/#```3L,2"_`%7"NEJ">9FYYS!PN8``=;F"`'"Y"`"'[)0@
MOP!5['0[OR55X]#PN``$['D`.@56PMI:@GF9N0@`>+D(`-#KA0`"``SLA0`A
M'E:Y@@`8N8``&;F"`!.Y"``[N0@`T>.P\,@`!,*Z6H)YF>QG(+\`5>Q((+\`
M5>P7.[\E5>P7&SH%5KD(`!WKV0`"``SLV0`A'E:Y@@"-N8``AKF"`(2Y"`!+
MX[#PT``$PKI:@GF9['$@OP!5[)T@OP!5N0@`@^PQ.[\E5>PQ&SH%5NL6``(`
M#+D(`#CL%@`A'E:Y!`!AN8(`UKF``->Y@@#9N0@`F^.P\-@`!,*Z6H)YF>R#
M(+\`5;D(`-3`&@````#L0SN_)57L0QLZ!5;K-P`"``RY"`!-[#<`(1Y6N00`
M<[F"`&>Y@`!HN8(`8;D(`!OCL/#@``3"NEJ">9GLU""_`%6Y"`!IP#H`````
M[)0[OR55[)0;.@56ZT@``@`,N0@`ENQ(`"$>5KD$`(2Y@@!XN8``?;F"`'.Y
M"``[X[#PZ``$PKI:@GF9[&D@OP!5N0@`<<!*`````.P9.[\E5>P9&SH%5NN=
M``(`#+D(`!?LG0`A'E:Y!`#9N8(`C;F``(:Y@@"$N0@`2^.P\/``!,*Z6H)Y
MF>QQ(+\`5;D(`(/`F@````#L,3N_)57L,1LZ!5;K%@`"``RY"``X[!8`(1Y6
MN00`8;F"`-:Y@`#7N8(`V;D(`)OCL/#X``3"NEJ">9GL@R"_`%6Y"`#4P!H`
M````[$,[OR55[$,;.@56ZS<``@`,N0@`3>PW`"$>5KD$`'.Y@@!GN8``:+F"
M`&&Y"``;X[#Q```$PKI:@GF9[-0@OP!5N0@`:<`Z`````.R4.[\E5>R4&SH%
M5NM(``(`#+D(`);L2``A'E:Y!`"$N8(`>+F``'VY@@!SN0@`.^.P\0@`!,*Z
M6H)YF>QI(+\`5;D(`''`2@````#L&3N_)57L&1LZ!5;KG0`"``RY"``7[)T`
M(1Y6N00`V;F"`(VY@`"&N8(`A+D(`$NY"`"#X[#Q$``$PKI:@GF9['$@OP!5
MP)H`````[#$[OR55[#$;.@56ZQ8``@`,N0@`..P6`"$>5NR#(+\`5;D$`&&Y
M@@#6N8``U[F"`-FY"`";N0@`U..P\1@`!.Q#.[\E5<*Z6H)YF>Q#&SH%5KD(
M`$W`&@````#LU""_`%7K-P`"``SL-P`A'E:Y!`!SP#H`````N8(`9[F``&BY
M@@!AN0@`&[D(`&GCL/$@``3LE#N_)57"NEJ">9GLE!LZ!5;K2``"``RY"`"6
M[$@`(1Y6N00`A+F"`'BY@`!]N8(`<[D(`#OL:2"_`%6Y"`!QP$H`````[!D[
MOR55X[#Q*``$[!D;.@56PKI:@GF9N0@`%^N=``(`#.R=`"$>5KF"`(FY@`"&
MN8(`A+D(`$NY"`"#[#$[OR55[#$;.@56N0@`..QQ(+\`5>R#(+\`5>S9(+\`
M5>L6``(`#..P\3``!.P6`"$>5L*Z6H)YF>QA(+\`5;F"`)&Y@`"7N8(`G;D(
M`-NY"`"4[$,[OR55[$,;.@56ZS<``@`,[#<`(1Y6N8(`$[F``!BY@@`6N0@`
M';D(`$GL<R"_`%7LE""_`%7LU#N_)57CL/$X``3LU!LZ!5;"NEJ">9FY"`#1
MN0@`:^L8``(`#.P8`"$>5KF"`#&Y@``YN8(`-[D(`#;L32"_`%7L@2"_`%7L
M;3N_)57L;2`Z!5:Y"`!CZSD``@`,[#D`(1Y6XY#Q0``$N8(`$\*:6H)YF;F`
M`!2Y"`!YN8(`&+D(`!?KE``"``SL=CN_)57LE``A'E;L=B`Z!5:YYY!#N0@`
M<;F"`$;C$/%(``3"&F[9ZZ&Y"``8N1H`%.R'.[\E5>R'(#H%5KD(`('L%B*_
M/E7L%@(A'E:Y!`!AXT#Q6``$XQ#Q4``$PAINV>NAN1H`$[GG8#FY@@`WN1H`
M$[D$`#'L&#N_)57L&"`Z!5:Y"``3[#<BOSY5[#<"(1Y6PDINV>NAN00`<[D:
M`$FYYS`VN8(`..R8(K\^5;D:`$/LF`(A'E:Y!``TN>>0A[F"`('L03N_)57L
M02`Z!5:Y"`!#XS#Q8``$PCINV>NAN1H`-KD:`#BY!`"#[#0[OR55[#0@.@56
MN0@`..R!(K\^5>R!`B$>5N,0\6@`!,(:;MGKH;D:`!>YYX!YN8(`=+D:`!>Y
M!`!Q[!,[OR55[!,@.@56N0@`%^QT(K\^5>QT`B$>5N-`\7``!,)*;MGKH;D:
M`$FYYW"8N8(`D[D:`$FY!`"4[$$[OR55[$$@.@56N0@`2>R3(K\^5>R3`B$>
M5N,P\7@`!,(Z;MGKH;D:`#BYYY"'N8(`@;D:`#BY!`"#[#0[OR55[#0@.@56
MN0@`..R!(K\^5>R!`B$>5N,0\8``!,(:;MGKH;D:`!>YYX!YN8(`=+D:`!>Y
M!`!Q[!,[OR55[!,@.@56N0@`%^QT(K\^5>QT`B$>5N-`\8@`!,)*;MGKH;D:
M`$FYYW"8N8(`D[D:`$FY!`"4[$$[OR55[$$@.@56N0@`2>R3(K\^5>R3`B$>
M5N,P\9``!,(Z;MGKH;D:`#BYYY"'N8(`@;D:`#BY!`"#[#0[OR55[#0@.@56
MN0@`..R!(K\^5>R!`B$>5N,0\9@`!,(:;MGKH;D:`!>YYX!YN8(`=+D:`!>Y
M!`!Q[!,[OR55[!,@.@56N0@`%^QT(K\^5>QT`B$>5N-`\:``!,)*;MGKH;D:
M`$FYYW"8N8(`D[D:`$FY!`"4[$$[OR55[$$@.@56N0@`2>R3(K\^5>R3`B$>
M5N,P\:@`!,(Z;MGKH;D:`#BYYY"'N8(`@;D:`#BY!`"#[#0[OR55[#0@.@56
MN0@`..R!(K\^5>R!`B$>5N,0\;``!,(:;MGKH;D:`!>YYX!YN8(`=+D:`!>Y
M!`!Q[!,[OR55[!,@.@56N0@`%^QT(K\^5>QT`B$>5N-`\;@`!,)*;MGKH;D:
M`$FYYW"8N8(`D[D:`$FY!`"4[$$[OR55[$$@.@56N0@`2>R3(K\^5>R3`B$>
M5N,P\<``!,(Z;MGKH;D:`#BYYY"'N8(`@;D:`#BY!`"#[#0[OR55[#0@.@56
MN0@`..R!(K\^5>R!`B$>5N,0\<@`!,(:;MGKH;D:`!>YYX!YN8(`=+D:`!>Y
M!`!Q[!,[OR55[!,@.@56N0@`%^QT(K\^5>S1(K\^5>QT`B$>5NS1`B$>5N-`
M\=``!,)*;MGKH;D:`$FYYW"8N8(`D[D:`$GL8R*_/E6Y!`"4[&,"(1Y6[$$[
MOR55XS#QV``$[$$@.@56PCINV>NAN1H`.+GG8(>Y@@"!N00`';D:`#CCT/'@
M``3"VF[9ZZ&Y&@#7N0@`2;D$`(/LE""_`%7L-#N_)56Y!`!][#D`.@56N><0
MUKD(`#BY@@!-[(,@OP!5N1H`=.Q#.[\E5>Q#&SH%5NLY``(`#.PY`"$>5NR3
M(+\`5;GF,-&YY)"QN8``V+F!`-NY"`!'X[#QZ``$PKJ/&[S<N1H`MKD$`&NY
M"`!M[-0[OR55[-0;.@56['0@OP!5N>C01NO8``(`#.S8`"$>5KD$`(VYYM#3
MN>20.+F``->Y@0#3XS#Q\``$PCJ/&[S<N1H`,>L7``(`#+D(`-/L%P`A'E;L
M<2"_`%6YY'"X[&0@OP!5[#0[OR55[#0;.@56N0@`/;GF$-BY@`#6N8$`V^.P
M\?@`!,*ZCQN\W+D(`)NY"`#9[$,@OP!5[),[OR55[),;.@56N0@`G>O6``(`
M#.S6`"$>5KF!`!VY@``4N00`;;F``->Y@0#1XQ#R```$PAJ/&[S<N1H`&+D(
M`!WL.2"_`%7LB3N_)57LB1LZ!5:YZ("1ZQ0``@`,[!0`(1Y6[$$@OP!5N>1`
MMKGF$-:Y@`#3N8$`V^.P\@@`!,*ZCQN\W+D(`'NY"`#7[(D@OP!5['D[OR55
M['D;.@56N0@`?>O3``(`#.S3`"$>5KF!`!VY@``8N00`/;F``-2Y@0#1XQ#R
M$``$PAJ/&[S<N1H`%NQG.[\E5>QG&SH%5NR7(+\`5;D(`!VYZ&!Q[&<@OP!5
MZQ@``@`,[!@`(1Y6[($@OP!5N>2`L[GF$-.Y@`#9N8$`V^.P\A@`!,*ZCQN\
MW+D(`$NY"`#4[$<[OR55[$<;.@56N0@`3>O9``(`#.S9`"$>5KF!`!VY@``6
MN00`G;F``-BY@0#1XQ#R(``$PAJ/&[S<N1H`$[D(`-'L=""_`%7K%@`"``SL
M%@`A'E;L82"_`%6YY&"Y[#0[OR55[#0;.@56N0@`/;GF$-FY@`#7N8$`V^.P
M\B@`!,*ZCQN\W+D(`(NY"`#8[$,@OP!5[(,[OR55[(,;.@56N0@`C>O7``(`
M#.S7`"$>5KF!`!VY@``4N00`?;F``-:Y@0#1XQ#R,``$PAJ/&[S<N1H`&;D(
M`-'L.""_`%7K%``"``SL%``A'E;L02"_`%6YY$"W[)@[OR55[)@;.@56N0@`
MG;GF$->Y@`#3N8$`V^.P\C@`!,*ZCQN\W+D(`&NY"`#6[(D@OP!5[&D[OR55
M[&D;.@56N0@`;>O3``(`#.S3`"$>5KF!`!VY@``8N00`/;F``-2Y@0#1XQ#R
M0``$PAJ/&[S<N1H`%[D(`-'LEB"_`%7K&``"``SL&``A'E;L@2"_`%6YY("S
M['8[OR55['8;.@56N0@`?;GF$-.Y@`#9N8$`V^.P\D@`!,*ZCQN\W+D(`$NY
M"`#4[&<@OP!5[$<[OR55[$<;.@56N0@`3>O9``(`#.S9`"$>5KF!`!VY@``6
MN00`G;F``-BY@0#1XQ#R4``$PAJ/&[S<N1H`$[D(`-'L=""_`%7K%@`"``SL
M%@`A'E;L82"_`%6YY&"Y[#0[OR55[#0;.@56N0@`/;GF$-FY@`#7N8$`V^.P
M\E@`!,*ZCQN\W+D(`(NY"`#8[$,@OP!5[(,[OR55[(,;.@56N0@`C>O7``(`
M#.S7`"$>5KF!`!VY@``4N00`?;F``-:Y@0#1XQ#R8``$PAJ/&[S<N1H`&;D(
M`-'L.""_`%7K%``"``SL%``A'E;L02"_`%6YY$"W[)@[OR55[)@;.@56N0@`
MG;GF$->Y@`#3N8$`V^.P\F@`!,*ZCQN\W+D(`&NY"`#6[(D@OP!5[&D[OR55
M[&D;.@56N0@`;>O3``(`#.S3`"$>5KD$`#VYYM#1N>1`$[F``-BY@0#1XQ#R
M<``$PAJ/&[S<N1H`%^R6(+\`5;D(`-'L%CN_)57L%ALZ!5;K:``"``SL:``A
M'E;LAB"_`%6YY("SN0@`';GF8-.Y@`#9N8$`V^.P\G@`!,*ZCQN\W+D(`$OL
M<2"_`%6Y"`#4[$$[OR55[$$@.@56ZQD``@`,[!D`(1Y6N8$`8;F``&>Y!`"1
MN8``&+F!`!;C8/*```3":H\;O-RY&@!CZS<``@`,N0@`8>PW`"$>5KD(`$VY
M!`!S[!0[OR55[!0@.@56N0@`%KGG,&GC,/*(``2Y@@!DPCK*8L'6N0@`.+D:
M`#;L@3N_)57L9"*_/E7L@2`Z!5;L9`(A'E:Y"`"#N>=@U^,P\I``!+F"`-'"
M.LIBP=:Y&@`Y[)$BOSY5N1H`/>R1`B$>5KD$`$.YYY`6N8(`&.PX.[\E5>PX
M(#H%5KD(`#3C0/*8``3"2LIBP=:Y&@!'N1H`0;D$`!3CL/"@``3L0SN_)57L
M0R`Z!5:Y"`!![!@BOSY5[!@"(1Y6N00`@;GG@'FY@@!SXQ#RH``$PAK*8L'6
MN1H`%KD:`!>Y!`!Q[!0[OR55[!0@.@56N0@`%^QS(K\^5>QS`B$>5N,P\J@`
M!,(ZRF+!UKD:`#FYYW"8N8(`E+D:`#FY!`"3[#$[OR55[#$@.@56N0@`.>R4
M(K\^5>R4`B$>5N-`\K``!,)*RF+!UKD:`$BYYY"'N8(`@;D:`$BY!`"$[$,[
MOR55[$,@.@56N0@`2.R!(K\^5>R!`B$>5N,0\K@`!,(:RF+!UKD:`!>YYX!Y
MN8(`<[D:`!>Y!`!Q[!0[OR55[!0@.@56N0@`%^QS(K\^5>QS`B$>5N,P\L``
M!,(ZRF+!UKD:`#FYYW"8N8(`E+D:`#FY!`"3[#$[OR55[#$@.@56N0@`.>R4
M(K\^5>R4`B$>5N-`\L@`!,)*RF+!UKD:`$BYYY"'N8(`@;D:`$BY!`"$[$,[
MOR55[$,@.@56N0@`2.R!(K\^5>R!`B$>5N,0\M``!,(:RF+!UKD:`!>YYX!Y
MN8(`<[D:`!>Y!`!Q[!0[OR55[!0@.@56N0@`%^QS(K\^5>QS`B$>5N,P\M@`
M!,(ZRF+!UKD:`#FYYW"8N8(`E+D:`#FY!`"3[#$[OR55[#$@.@56N0@`.>R4
M(K\^5>R4`B$>5N-`\N``!,)*RF+!UKD:`$BYYY"'N8(`@;D:`$BY!`"$[$,[
MOR55[$,@.@56N0@`2.R!(K\^5>R!`B$>5N,0\N@`!,(:RF+!UKD:`!>YYX!Y
MN8(`<[D:`!>Y!`!Q[!0[OR55[!0@.@56N0@`%^QS(K\^5>QS`B$>5N,P\O``
M!,(ZRF+!UKD:`#FYYW"8N8(`E+D:`#FY!`"3[#$[OR55[#$@.@56N0@`.>R4
M(K\^5>R4`B$>5N-`\O@`!,)*RF+!UKD:`$BYYY"'N8(`@;D:`$BY!`"$[$,[
MOR55[$,@.@56N0@`2.R!(K\^5>R!`B$>5N,0\P``!,(:RF+!UKD:`!>YYX!Y
MN8(`<[D:`!>Y!`!Q[!0[OR55[!0@.@56N0@`%^QS(K\^5>QS`B$>5N,P\P@`
M!,(ZRF+!UKD:`#FYYW"8N8(`E+D:`#FY!`"3[&$BOSY5[#$[OR55[&$"(1Y6
M[#$@.@56N0@`.>R4(K\^5>R4`B$>5N-`\Q``!,)*RF+!UKD:`$BYYY"'N8(`
M@>,0\Q@`!,(:RF+!UKD:`!>YYV!YN8(`<[D:`$BY&@`7N00`A+D$`''L0SN_
M)57L0R`Z!5:Y"`!([(0@OP!5[!0[OR55[!@`.@56N0@`%^QS(K\^5>QS`B$>
M5N,P\R``!,(ZRF+!UKD(`#6YYW!6N1H`.;F"`$6Y&@`TN0@`H>-@("``"+D$
M`%/`J@````#CH"`(`"3L,3N_)56Y"`"W[#$;.@56P+H`````X[`@&``DN0@`
M-<!J`````.-@("``),`Z`````.,P(```).L8``(`#.P8`"$>5KD(``'`"@``
M``#C`"`0`"2R3P`0ZQ$`(``-LD\`$=4'\R@0**>$``7`Y?__YHWK;_-@``0'
M_@<'!P?K[_!P`"2G*0"`X_#_8/]QP.7__^/\P#%G12,!XS`@```DY4@@*```
MP#_OS:N)XS`@"``DY4@@,```P#^8NMS^XS`@$``DY4P@>```P#$0,E1VXS`@
M&``DP#_#TN'PXS`@(``DZ^_Q$``$!_X'!P<'ZV_P,``DZQ0``P`-N00`HKD$
M`+3C("`H``2Y"``2[$$@OP!5X_#_8/]QN3$`(:?$``7K`:`P`'KC0*`H`"3K
M&P`=``SC$*`P``CC$*`P`"1!D*`XXQ"@>``2IX0`-*>(`$`;@1F+N00`*;GR
ML(NY&``AN10`2+DA`".GI``&N>A`$KEA0#&YZ$!SN2$`(Z?$``2Y84`GP.7_
M_^71&!A:$*!X4!"@>*<>`$"G=``SN00`*ANXP.7___1*N10`N[D$`#?KBP`&
M`-ZGB@`!IQ@``1*[06"@>+GR4(&GA@`AN2$`.:?$``:YZ+`9N6%`,;DA`#FG
MI``&N>BP$[EA0)&Y!`!+N00`*<#E___EF5"PH'CK;_#0``0'_J?T``&Y(0`Y
MI\0`!KDA`#:G1/_XN2$`.4%P,$"GI``&N2$`EZ=$_^ZY!``JI[K_P+D4`+O2
M/Y``,`#`Y?__\_NY!``WI_3_O^N/\$``)+D$`*+CD#`H``3C@#`P``3L*3J_
M/57L$@`!`-BY%``B02(P.)*`(`#C\/]@_W&Y%``AN00`LT%",#BG'@`XI\0`
M6*<H`$"G60``N?D0$KD$`"2Y%@`QITD``*@D``"G%/_^N00`*\#E___SOM<W
ML#BP..L8`!@`#$(0L'!"@+!SZQ@`$``,0A"P<4*0L'?K&``(``Q"$+!RN00`
M*^L9`!@`#$(0L'3K&0`0``Q"$+!UZQD`"``,0A"P=L#E___SE+D$`"O2`Z``
ML`32`Z`$L`S2`Z`(L!32`Z`,L!S2`Z`0L"3KC_#@``3`]/__Y)6G*``XIUD`
M`+GY$!*Y!``DN18`,:=)``"H)```IQ3__J?T_[+KO_!8`"3C\/]@_W'`L```
M*PKC$+````2G'___IW0`!NN_\/@`!`?^X["_^/]Q#>&G]/_Q!P<'!^OO\'``
M)./P_V#_<>OO\1``!`?^!P<'!^OO\'``)+D$``^G^_]@XP#P```DP.7__^9^
MZ^_Q$``$!_XO=&UP```N`%!!4E]435!$25(``%1%35!$25(`5$U0`%5315(`
M`%5315).04U%```N+@``)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A
M9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4``!E>&4`+W!R;V,O)6DO)7,`4$%2
M7U1%35```%!!4E]04D]'3D%-10``.@`O`%!%4DPU3$E"``!015),3$E"`%!%
M4DPU3U!4``!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!0
M05)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'
M``!005)?1TQ/0D%,7U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!
M3%]#3$5!3@``4$%27T-,14%./0``,0!,1%],24)205)97U!!5$@`4UE35$5-
M```E,#)X``!P87(M```E<R5S)7,E<P``)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``4$%42```<&%R;```
M+G!A<@``)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,`)7,E<W1E;7`M
M)74M)74E<P``05)'5@``&`!P97)L``!005(Z.E!A8VME<CHZ5D524TE/3@``
M,2XP-3``56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``"UE```M+0``979A;"`G97AE8R`O=7-R+V)I;B]P
M97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD
M97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)
M0RP@)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@
M*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O
M<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U
M=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ
M1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK
M('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?
M=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL
M93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z
M.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G
M+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@
M=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII
M9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@
M,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M
M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@
M/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S
M92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O
M=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL
M96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@
M:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["B1005)?34%'24,@
M/2`B7&Y005(N<&U<;B(["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?
M<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE
M("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@
M)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\
M3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?
M<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C
M86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P
M<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S
M:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R
M-#L*;7D@)&UA9VEC7W!O<SL*:68@*"1S:7IE(#P]("1C:'5N:U]S:7IE*2![
M"B1M86=I8U]P;W,@/2`P.PI](&5L<VEF("@H;7D@)&T@/2`D<VEZ92`E("1C
M:'5N:U]S:7IE*2`^(#`I('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&T["GT@
M96QS92!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1C:'5N:U]S:7IE.PI]"G=H
M:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:RA?1D@L("1M86=I8U]P;W,L
M(#`I.PIR96%D*%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!
M4E]-04=)0RDI.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'
M24,I*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA9VEC
M7W!O<R`M/2`D8VAU;FM?<VEZ93L*?0IL87-T(&EF("1M86=I8U]P;W,@/"`P
M.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F
M+"`T.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D
M8G5F*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI
M<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@
M("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&
M24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q
M*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H
M("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD
M968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I
M/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD
M("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M
M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*
M96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D
M("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H
M(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F
M:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE
M?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB
M=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I]
M.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*
M;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U
M;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@9&5L971E("1R97%U:7)E7VQI
M<W1[)&UO9'5L97T@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D
M97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E
M9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN
M97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H
M("1I;F9O+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]
M"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1I;F9O+3Y[8W)C
M?2YP;2(L("1I;F9O+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE
M;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO
M9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I
M;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I
M<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@
M*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI
M('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"
M4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U
M:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D
M9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@
M)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@
M97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[
M("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S
M.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E
M;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M
M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D
M14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@
M97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@
M/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI
M;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@
M*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%2
M1U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E
M('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H
M:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V
M72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T
M;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R
M(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H
M)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q
M("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@
M>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G
M9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A
M(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR
M97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD[
M"FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\
M)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM
M;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E
M860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z
M:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI
M('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO
M+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C
M86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG
M+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B
M)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP
M,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE
M.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O
M<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P
M;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@
M)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)
M37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T
M(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD
M=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC
M(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@
M(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA
M9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@
M+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*
M)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D[
M"G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.
M+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N
M9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O
M;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[
M)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L
M=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E
M>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@
M>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2![
M"FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F
M:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C
M72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]
M"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H
M;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F
M:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B
M)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D[
M"FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO
M="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@
M)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q
M*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL
M92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2![
M"B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L
M("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I
M;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E
M9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M
M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]
M"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)
M3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI
M*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII
M<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D
M8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF
M("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T
M,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U
M="DI6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N
M*&UY("1F:"P@(CPB+"`D;W5T*3L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F
M:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C86-H95]N86UE(#T@)&-T>"T^:&5X
M9&EG97-T.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@
M)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R
M:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT
M96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)
M0RD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL
M87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H
M*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ
M2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B
M)"$Z("1`(CL*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*
M;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHD>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2!O<B!D:64@(B0A.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3
M:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.
M5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6
M>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@
M(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE
M;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$
M:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE
M.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH
M/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA
M;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H
M)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?
M;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@
M>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L
M<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S
M*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B
M*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*
M8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]
M"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE
M(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=
M(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M
M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6
M*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I
M(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI
M.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T
M:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R
M"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E
M($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0[
M"G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&
M8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,[
M"G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/
M.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z
M.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ
M4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R
M:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@
M5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@
M>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q
M=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER
M92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E
M<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN
M960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A
M=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-
M4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN
M97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@
M)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED
M*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE
M9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ
M3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA
M;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!
M345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^
M(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM
M?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]
M("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D
M<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@
M)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M
M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G
M.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68[
M"GT*96QS92!["FUY("1D:6=E<W0@/2!E=F%L"GL*<F5Q=6ER92!$:6=E<W0Z
M.E-(03L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96XH;7D@
M)&9H+"`B/"(L("1P<F]G;F%M92D["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D
M9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8W1X+3YH97AD:6=E<W0["GT@?'P@
M)&UT:6UE.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M)&1I
M9V5S="(["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y]
M(#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]
M"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P
M-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!]
M(&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL
M92!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U
M;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN
M86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY
M("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M
M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',[
M"F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D
M("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN
M:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?
M<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD
M("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@
M)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N
M9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P
M<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L
M("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.
M04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@
M,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R
M;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5]
M(BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*
M9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%
M+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0
M?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O
M;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2([
M"B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@
M)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N
M9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E
M=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T
M0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D[
M"B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I
M+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%2
M7TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.
M5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%
M35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%
M3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$
M14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?
M)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@
M)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%
M04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI
M('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H
M*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^
M("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF
M("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]
M"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U
M:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N
M9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I
M=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E
M>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)
M3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*
M9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N
M86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@
M)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D
M0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*
M)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D
M.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?
M15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``'!E<FQX<VDN8P!?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(````1L#.P```-`````9
M__^,?```!*C__Y"<````[/__D4P```$H__^1G````4C__Y(T```!>/__E(P`
M``&T__^5[````>S__Y:,```"&/__ELP```(X__^7+````G3__YA$```"L/__
MF$P```+$__^:/````P#__YI<```#%/__FY0```,X__^='````US__YV,```#
MB/__G;P```.H__^>;````_3__Z2\```$,/__J'P```1L__^H[```!.S__[\T
M```%*/__OZ0```5,___!!```!8@````4``````%Z4@`!>`X!&PP/H`$`````
M```X````'/__CZ@```"P`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.P`("@@K/
MSLW,R\K)R,?&#J`!0@L````<````6/__D!P```!0`%2.!H\%1@[0`G3/S@Z@
M`0```"P```!X__^03````)@`2HH*BPF,"(T'C@:/!48.T`("AL_.S<S+R@Z@
M`0```````#@```"H__^0M````E(`2H8.APV(#(D+B@J+"8P(C0>.!H\%1@[0
M`@,"0,_.S<S+RLG(Q\8.H`$``````#0```#D__^2T````5X`2H<-B`R)"XH*
MBPF,"(T'C@:/!48.V`,#`4S/SLW,R\K)R,<.H`$`````*````1S__Y/X````
MG`!4BPF,"(T'C@:/!48.V`,"@,_.S<S+#J`!```````<```!2/__E&P````\
M`$R.!H\%1@[``F3/S@Z@`0```#@```%H__^4C````%H`1H8.APV(#(D+B@J+
M"8P(C0>.!H\%1@[(`@),S\[-S,O*R<C'Q@Z@`0```````#@```&D__^4L```
M`18`2H8.APV(#(D+B@J+"8P(C0>.!H\%1@[00@,!!,_.S<S+RLG(Q\8.H`$`
M`````!````'@__^5C`````8`````````.````?3__Y6````![@!*A@Z'#8@,
MB0N*"HL)C`B-!XX&CP5&#N`C`P'<S\[-S,O*R<C'Q@Z@`0``````$````C#_
M_Y<T````'@`````````@```"1/__ET````$V``+\C@:/!48.P`)8S\X.H`$`
M```````@```":/__F%0```&(`%2.!H\%1@[P`@,!;,_.#J`!```````H```"
MC/__F;@```!P`%J.!H\%1@[``GX*S\X.H`%""T@.H`'.SP```````!P```*X
M__^9_````"X`1HX&CP5&#L`"8,_.#J`!````2````MC__YH,````K`!&A@Z'
M#8@,B0N*"HL)C`B-!XX&CP5*#L`";`K/SLW,R\K)R,?&#J`!1@L":,_.S<S+
MRLG(Q\8.H`$``````#@```,D__^:<```!DH`5(8.APV(#(D+B@J+"8P(C0>.
M!H\%1@Z(A0(#!B[/SLW,R\K)R,?&#J`!`````#@```-@__^@A````\``1H8.
MAPV(#(D+B@J+"8P(C0>.!H\%1@[``@,#LL_.S<S+RLG(Q\8.H`$``````#@`
M``.<__^D"````&P`1HH*BPF,"(T'C@:/!48.P`("4@K/SLW,R\H.H`%&"T;/
MSLW,R\H.H`$``````$````/8__^'S````BH`1H8.APV(#(D+B@J+"8P(C0>.
M!H\%1@[8`@,!\@K/SLW,R\K)R,?&#J`!0@L`````````````.```!!S__Z/X
M```61`!8A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M`'`Q8DS\[-S,O*R<C'Q@Z@
M`0``````(```!%C__[H$````;`!*C@:/!48.P`("6L_.#J`!````````.```
M!'S__[I0```!8`!,A@Z'#8@,B0N*"HL)C`B-!XX&CP5>#L`"`NP*S\[-S,O*
MR<C'Q@Z@`4(+````-```!+C__[MT```!&`!&B`R)"XH*BPF,"(T'C@:/!6X.
MP`("N@K/SLW,R\K)R`Z@`48+````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#__________P``````````____
M______\````````````````````!``````````$``````````0````````*R
M``````````\````````$-@`````````,````````&'``````````#0``````
M`%8(`````&___O4````````"&``````````%````````#"``````````!@``
M``````+P``````````H````````$5``````````+`````````!@`````````
M%0````````````````````,```````"MF``````````"````````!8@`````
M````%``````````'`````````!<````````2Z``````````'````````$'@`
M````````"`````````)P``````````D`````````&``````````8````````
M````````;___^P`````(```!`````&____D`````````#@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````J_@`````````````````
M````````````&,8````````8Y@```````!D&````````&28````````91@``
M`````!EF````````&88````````9I@```````!G&````````&>8````````:
M!@```````!HF````````&D8````````:9@```````!J&````````&J8`````
M```:Q@```````!KF````````&P8````````;)@```````!M&````````&V8`
M```````;A@```````!NF````````&\8````````;Y@```````!P&````````
M'"8````````<1@```````!QF````````'(8````````<I@```````!S&````
M````'.8````````=!@```````!TF````````'48````````=9@```````!V&
M````````':8````````=Q@```````!WF````````'@8````````>)@``````
M`!Y&````````'F8````````>A@```````!ZF````````'L8````````>Y@``
M`````!\&````````'R8````````?1@```````!]F````````'X8````````?
MI@```````!_&````````'^8````````@!@```````"`8````````````````
M`````````````%8(`````````````````````````````!AP````````````
M````````````````````````````````````````````````````````````
M`````````````````````+``_____P````````````!6*@```````%8P````
M``````````````!6,@```````%8V````````5CX```````!6J@```````%9&
M``````````````````!62@```````%90``````````````````!9"D=#0SH@
M*$%L<&EN92`Y+C,N,"D@.2XS+C```"YS:'-T<G1A8@`N:6YT97)P`"YG;G4N
M:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI
M=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE
M`"YC=&]R<P`N9'1O<G,`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM
M96YT````````````````````````````````````````````````````````
M```````````````````````````````````````+`````0`````````"````
M`````@`````````"```````````8`````````````````````0``````````
M````$V____8``````````@````````(8`````````A@`````````V`````,`
M``````````````@``````````````!T````+``````````(````````"\```
M``````+P````````"3`````$`````@`````````(`````````!@````E````
M`P`````````"````````#"`````````,(`````````14````````````````
M`````0``````````````+0````0``````````@```````!!X````````$'@`
M```````"<`````,```````````````@`````````&````#<````$````````
M`$(````````2Z````````!+H````````!8@````#````$0`````````(````
M`````!@```!!`````0`````````&````````&'`````````8<``````````H
M`````````````````````@``````````````/`````$`````````!@``````
M`!B8````````&)@````````'@`````````````````````0`````````(```
M`$<````!``````````8````````@&````````"`8````````-?``````````
M```````````(``````````````!-`````0`````````&````````5@@`````
M``!6"``````````B`````````````````````@``````````````4P````$`
M`````````@```````%8J````````5BH````````]<@``````````````````
M``(``````````````%L````!``````````(```````"3G````````).<````
M`````-0````````````````````$``````````````!I`````0`````````"
M````````E'````````"4<`````````3P````````````````````"```````
M````````<P````$``````````P```````*O8````````F]@`````````$```
M``````````````````@``````````````'H````!``````````,```````"K
MZ````````)OH`````````!`````````````````````(``````````````"!
M````!@`````````#````````J_@```````";^`````````&@````!```````
M````````"``````````0````B@````$``````````P```````*V8````````
MG9@````````":`````````````````````@`````````"````(\````!````
M``````,```````"P`````````*```````````'@````````````````````(
M``````````````"5````"``````````#````````L'@```````"@>```````
M`!!@````````````````````"```````````````F@````$`````````,```
M````````````````H'@`````````&@````````````````````$`````````
M`0````$````#`````````````````````````````*"2`````````*,`````
4```````````````!````````````
